classdef DiscoveryMessage < handle
  % DiscoveryMessage
  %   A gige discovery message containing camera information
  %
  % Methods:
  %   ip - Get the camera's ip address
  %   serial - Get the camera's serial
  %

  properties(Access=protected)
    mPtr = uint64(0);
  end

  methods(Access=public)
    function obj = DiscoveryMessage(varargin)
      % DiscoveryMessage
      %   Construct new discovery_message class
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        obj.mPtr = varargin{1};
      else
        error("Can't construct empty object");
      end
    end

    function delete(obj)
      if obj.mPtr ~= 0
        tof.mex('tof_discovery_message_delete', obj.mPtr);
        obj.mPtr = 0;
      end
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function ret_val = ip(obj)
      % ip
      %   Get the camera's ip address
      %
      % Output:
      %   ret_val - string - Ip address
      %

      ret_val = tof.mex('tof_discovery_message_ip', obj.mPtr);
    end

    function ret_val = serial(obj)
      % serial
      %   Get the camera's serial
      %
      % Output:
      %   ret_val - string - Serial
      %

      ret_val = tof.mex('tof_discovery_message_serial', obj.mPtr);
    end

  end
end
