# Example of using OpenCV haarcascades and the ToF intensity information to performe face detection
# This is an outdated method of face detection, but is shipped with opencv.
import chronoptics.tof as tof
import numpy as np
import cv2

# Camera serial
serial = "202001a"

# OpenCV Haarcascade Face Detection file (Provided by OpenCV)
cas_file = cv2.data.haarcascades + "haarcascade_frontalface_alt2.xml"

# Frame types to capture
types = [tof.FrameType.INTENSITY, tof.FrameType.Z]


cam = tof.KeaCamera(tof.ProcessingConfig(), serial)
faceCascade = cv2.CascadeClassifier(cas_file)

tof.selectStreams(cam, types)

# Start the camera
cam.start()


while cam.isStreaming():
    frames = cam.getFrames()

    gray = np.uint8(np.squeeze(np.asarray(frames[0])))
    zframe = np.uint8((np.asarray(frames[1]) / 2700.0) * 255)

    faces = faceCascade.detectMultiScale(
        gray,
        scaleFactor=1.1,
        minNeighbors=5,
        minSize=(15, 15),
        flags=cv2.CASCADE_SCALE_IMAGE,
    )

    for (x, y, w, h) in faces:
        cv2.rectangle(gray, (x, y), (x + w, y + h), (0, 255, 0), 2)

    cv2.imshow("amplitude", gray)
    cv2.imshow("distance", zframe)

    if cv2.waitKey(1) & 0xFF == ord("q"):
        cam.stop()
